@@ -11,14 +11,11 @@ define('SM_PATH','../../');
 require_once(SM_PATH . 'include/validate.php');
 
 
-global $username, $data_dir, $_SERVER, $browser_info;
-
+        global $username, $data_dir, $_SERVER, $browser_info;
 $username = $_SESSION['username'];
-$browser_info['type'] = $_SESSION['browser']['type'];
-$broswer_info['version'] = $_SESSION['browser']['version'];
 $Type = getPref($data_dir,$username, 'compose_window_type');
 
-if (stristr($_SERVER['SCRIPT_NAME'], "compose.php") and $Type == 'html' and $browser_info['type'] == "Explorer" and $broswer_info['version'] >= '5.5' )  {
+if (stristr($_SERVER['SCRIPT_NAME'], "compose.php") and $Type == 'html' and $_SESSION['browser_info']['type'] == 'Explorer' and $_SESSION['browser_info']['version'] >= '5.5' )  {
 
 include '../plugins/emoticons/emoticons.php';
 
